use crossterm::event::{KeyEvent, KeyCode};
use color_eyre::Result;
use ratatui::{
    layout::{Constraint, Flex, Layout, Rect}, 
    widgets::{Block, Clear}, 
    Frame
};

use super::{Component, PartialComponent, CurrentTab};
use crate::{
    action::Action, 
    config::Config, 
    palette::StylePalette, 
};

#[derive(Debug)]
pub struct AddAddress {
    is_shown: bool,
    palette: StylePalette
}

impl Default for AddAddress {
    fn default() -> Self {
        Self::new()
    }
}

impl AddAddress {
    pub fn new() -> Self {
        Self {
            is_shown: false,
            palette: StylePalette::default(),
        }
    }
}

impl PartialComponent for AddAddress {
    fn set_active(&mut self, _current_tab: CurrentTab) {}
}

impl Component for AddAddress {
    fn register_config_handler(&mut self, config: Config) -> Result<()> {
        if let Some(style) = config.styles.get(&crate::app::Mode::Explorer) {
            self.palette.with_normal_style(style.get("normal_style").copied());
            self.palette.with_hover_style(style.get("hover_style").copied());
            self.palette.with_normal_border_style(style.get("normal_border_style").copied());
            self.palette.with_hover_border_style(style.get("hover_border_style").copied());
            self.palette.with_normal_title_style(style.get("normal_title_style").copied());
            self.palette.with_hover_title_style(style.get("hover_title_style").copied());
        }
        Ok(())
    }

    fn handle_key_event(&mut self, key: KeyEvent) -> Result<Option<Action>> {
        match key.code {
            KeyCode::Char('a') => self.is_shown = true, 
            KeyCode::Char(' ') => self.is_shown = false, 
            _ => {},
        };
        Ok(None)
    }

    fn update(&mut self, action: Action) -> Result<Option<Action>> {
        match action {
            _ => {}
        };
        Ok(None)
    }

    fn draw(&mut self, frame: &mut Frame, area: Rect) -> Result<()> {
        if self.is_shown {
            let block = Block::bordered().title("Transfer");
            let v = Layout::vertical([Constraint::Min(55)]).flex(Flex::Center);
            let h = Layout::horizontal([Constraint::Min(10)]).flex(Flex::Center);
            let [area] = v.areas(area);
            let [area] = h.areas(area);
            frame.render_widget(Clear, area);
            frame.render_widget(block, area);
        }
        Ok(())
    }
}
